==> jwinner-base-0.0.3-sources.jar: itez/plat/base/model/base/BaseMenu.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseMenu<M extends BaseMenu<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setCompId(java.lang.String compId) {
		set("compId", compId);
		return (M)this;
	}
	
	public java.lang.String getCompId() {
		return getStr("compId");
	}

	public M setIco(java.lang.String ico) {
		set("ico", ico);
		return (M)this;
	}
	
	public java.lang.String getIco() {
		return getStr("ico");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setCommand(java.lang.String command) {
		set("command", command);
		return (M)this;
	}
	
	public java.lang.String getCommand() {
		return getStr("command");
	}

	public M setAuthMode(java.lang.String authMode) {
		set("authMode", authMode);
		return (M)this;
	}
	
	public java.lang.String getAuthMode() {
		return getStr("authMode");
	}

	public M setAuthCode(java.lang.String authCode) {
		set("authCode", authCode);
		return (M)this;
	}
	
	public java.lang.String getAuthCode() {
		return getStr("authCode");
	}

	public M setPath(java.lang.String path) {
		set("path", path);
		return (M)this;
	}
	
	public java.lang.String getPath() {
		return getStr("path");
	}

	public M setFolder(java.lang.Integer folder) {
		set("folder", folder);
		return (M)this;
	}
	
	public java.lang.Integer getFolder() {
		return getInt("folder");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.1.0-sources.jar: itez/plat/base/model/base/BaseMenu.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseMenu<M extends BaseMenu<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setCompId(java.lang.String compId) {
		set("compId", compId);
		return (M)this;
	}
	
	public java.lang.String getCompId() {
		return getStr("compId");
	}

	public M setMtype(java.lang.String mtype) {
		set("mtype", mtype);
		return (M)this;
	}
	
	public java.lang.String getMtype() {
		return getStr("mtype");
	}

	public M setIco(java.lang.String ico) {
		set("ico", ico);
		return (M)this;
	}
	
	public java.lang.String getIco() {
		return getStr("ico");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setCommand(java.lang.String command) {
		set("command", command);
		return (M)this;
	}
	
	public java.lang.String getCommand() {
		return getStr("command");
	}

	public M setAuthMode(java.lang.String authMode) {
		set("authMode", authMode);
		return (M)this;
	}
	
	public java.lang.String getAuthMode() {
		return getStr("authMode");
	}

	public M setAuthCode(java.lang.String authCode) {
		set("authCode", authCode);
		return (M)this;
	}
	
	public java.lang.String getAuthCode() {
		return getStr("authCode");
	}

	public M setPath(java.lang.String path) {
		set("path", path);
		return (M)this;
	}
	
	public java.lang.String getPath() {
		return getStr("path");
	}

	public M setFolder(java.lang.Integer folder) {
		set("folder", folder);
		return (M)this;
	}
	
	public java.lang.Integer getFolder() {
		return getInt("folder");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
